Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(202)

Unified Diff: third_party/WebKit/Source/core/frame/LocalFrameClient.h

Issue 2764993002: CSP: group policies in didAddContentSecurityPolicy. (Closed)
Patch Set: Rebase. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/frame/LocalFrameClient.h
diff --git a/third_party/WebKit/Source/core/frame/LocalFrameClient.h b/third_party/WebKit/Source/core/frame/LocalFrameClient.h
index 5f4b2c2a909e8967d911d0b82bcfe87d172c5d00..d6391756963d0dac7756c2600ee7bb48c10fabc8 100644
--- a/third_party/WebKit/Source/core/frame/LocalFrameClient.h
+++ b/third_party/WebKit/Source/core/frame/LocalFrameClient.h
@@ -280,14 +280,12 @@ class CORE_EXPORT LocalFrameClient : public FrameClient {
virtual void didSetFeaturePolicyHeader(
const WebParsedFeaturePolicy& parsedHeader) {}
- // Called when a new Content Security Policy is added to the frame's document.
- // This can be triggered by handling of HTTP headers, handling of <meta>
- // element, or by inheriting CSP from the parent (in case of about:blank).
- virtual void didAddContentSecurityPolicy(
- const String& headerValue,
- ContentSecurityPolicyHeaderType,
- ContentSecurityPolicyHeaderSource,
- const std::vector<WebContentSecurityPolicy>&) {}
+ // Called when a set of new Content Security Policies is added to the frame's
+ // document. This can be triggered by handling of HTTP headers, handling of
+ // <meta> element, or by inheriting CSP from the parent (in case of
+ // about:blank).
+ virtual void didAddContentSecurityPolicies(
+ const blink::WebVector<WebContentSecurityPolicy>&) {}
virtual void didChangeFrameOwnerProperties(HTMLFrameElementBase*) {}
« no previous file with comments | « content/renderer/render_frame_proxy.cc ('k') | third_party/WebKit/Source/core/frame/csp/ContentSecurityPolicy.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698